local effects = require(mod_name .. ".lualib.effects")
local pollution = require(mod_name .. ".lualib.pollution")
local quest_gui = require(mod_name .. ".lualib.quest_gui")
local check = require(mod_name .. ".lualib.check")
local attacks = require(mod_name .. ".lualib.attacks")
local locations = require(mod_name .. ".lualib.locations")
local popup = require(mod_name .. ".lualib.popup")
local attack = require(mod_name .. ".lualib.attacks")
local cutscene = require(mod_name .. ".lualib.cutscene")
local scenes = require(mod_name .. '.lualib.npe.scenes')
local expansions = require(mod_name .. '.lualib.npe.expansions')
local colony_controller = require(mod_name .. '.lualib.colony_controller')

local second_base = {}

second_base.story_nodes = {}

second_base.story_nodes['reach-pond'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'arrive',
      },
    }

    global.compilatron.reset = true
    game.forces['player'].set_spawn_position(locations.get_pos('pond-player-spawn'),locations.get_main_surface())
    quest_gui.set('reach-pond', quest_layout)
    effects.turn_biters_hostile('starting-area')
    quest_gui.visible(true)
    locations.get_main_surface().clear_pollution()
  end,

  update = function()
    effects.turn_biters_around({ 'safe-1', 'safe-2', 'safe-3', 'safe-4'},'crash-site')
  end,

  condition = function()
    return check.player_inside_area('pond', false)
  end,

  action = function()
    effects.turn_biters_hostile('starting-area')
    quest_gui.visible(false)
  end,
}


second_base.story_nodes['rebuild'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'research-improved-equipment',
      },
      {
        item_name = 'power-lab',
        icons = {'item/lab'},
        children =
        {
          {
            item_name = 'connection',
            icons = {'item/small-electric-pole'},
            children =
            {
              {
                item_name = 'provide-steam',
                icons = {'item/steam-engine','fluid/steam'},
                children =
                {
                  {
                    item_name = 'provide-water',
                    icons = {'item/boiler','fluid/water','item/coal'},
                    children =
                    {
                      {
                        item_name = 'build-offshore-pump',
                        icons = {'item/offshore-pump'},
                      },
                    }
                  },
                }
              },
            }
          }
        }
      },
    }

    effects.unlock_technologies('rebuild')
    global.compilatron.reset = true
    quest_gui.set('rebuild', quest_layout)
    quest_gui.visible(true)
    game.auto_save("rebuild")
  end,

  condition = function(event)
    -- these checks are expensive, so only do them once a second
    if event.tick % 60 ~= 0 then return end

    check.steam_engine_operational()
    check.entity_powered('lab')
    local researched = check.research_list_complete({'improved-equipment'})
    return researched
  end,

  action = function()
    quest_gui.visible(false)
  end
}

second_base.story_nodes['military'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'player-loaded',
        children =
        {
          {
            item_name = 'craft-firearm-magazine',
            icons = {'item/firearm-magazine'},
            goal = 10
          },
        }
      },
      {
        item_name = 'craft-pistol',
        icons = {'item/pistol'},
        goal = 1,
        children =
        {
          {
            item_name = 'research-basic-military',
          },
        }
      },
    }

    locations.get_main_surface().always_day = false
    effects.unlock_technologies('military')
    global.compilatron.reset = true
    quest_gui.set('military', quest_layout)
    quest_gui.add_hint({'quest-hints.info-handcrafting'})
    quest_gui.visible(true)
  end,

  condition = function()
    local researched = check.research_list_complete({'basic-military'})
    local crafted = check.player_crafted_list(
      {
        {name='pistol',goal=1},
        {name='firearm-magazine',goal=10}
      })
    local loaded = check.player_is_loaded()
    return researched and crafted and loaded
  end,

  action = function()
    pollution.reset()
    quest_gui.visible(false)
  end,
}


second_base.story_nodes['entrench'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'stockpile-firearm-magazine',
        icons = {'item/firearm-magazine'},
        goal = 100
      },
      {
        item_name = 'loaded-second-base-area',
        icons = {'item/gun-turret'},
        goal = 2,
        children =
        {
          {
            item_name = 'research-active-defense',
          },
        }
      },
    }

    effects.unlock_technologies('entrench')
    global.compilatron.reset = true
    quest_gui.set('entrench', quest_layout)
    quest_gui.add_hint({'quest-hints.info-test-fire'})
    quest_gui.visible(true)

    quest_gui.add_hint({'quest-hints.info-turret-ammo'})
    quest_gui.add_hint({'quest-hints.info-repair-pack'})
  end,

  condition = function(event)
    -- these checks are expensive, so only do them once a second
    if event.tick % 60 ~= 0 then return end

    local stockpile = check.player_stockpiled_list(
    {
      {name='firearm-magazine',goal=100}
    })
    local loaded = check.number_of_loaded_turrets_in_areas({'second-base-area'}, 2, true)
    --loaded = loaded or check.number_of_loaded_turrets_in_areas({'starting-area'}, 1, false)
--[[    if loaded then
      quest_gui.update_count('loaded-second-base-area', 1, 1)
    else
      quest_gui.update_count('loaded-east-expansion', 0, 1)
    end]]

    local researched = check.research_list_complete({'active-defense'})
    return researched and loaded and stockpile
  end,
  update = function()
    attacks.check_spawn_wave('pistol-west')
  end,
  action = function()
    quest_gui.unset()
  end,
}

second_base.story_nodes['trigger-west-spawner'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'arrive-compi-trigger-cutscene-pond',
      },
    }

    global.compilatron.reset = true
    quest_gui.set('trigger-west-spawner', quest_layout)
    quest_gui.visible(true)
  end,

  update = function()
    attacks.check_spawn_wave('pistol-west')
  end,

  condition = function()
    local arrive = check.player_inside_area('compi-trigger-cutscene-pond')
    return arrive
  end,

  action = function()
    quest_gui.visible(false)
  end
}

second_base.story_nodes['biters-from-west'] =
{
  init = function()
    popup.clear_all()
    cutscene.play(scenes['biters-from-west'])
  end,
  condition = function()
    return not cutscene.is_any_cutscene_playing()
  end
}

second_base.story_nodes['fortify'] =
{
  init = function()
    -- This node is used as a migration target.
    -- This means that this init function can be called multiple times, so care must be taken to make sure it's ok to do that.

    local quest_layout =
    {
      {
        item_name = 'produce-per-time-firearm-magazine',
        icons ={'item/firearm-magazine'},
        goal = 50,
        unit = 'pm',
      },
      {
        item_name = 'consume-per-time-automation-science-pack',
        icons ={'item/automation-science-pack'},
        goal = 12,
        unit = 'pm',
      },
      {
        item_name = 'loaded-defend-2',
        icons = {'item/gun-turret'},
        goal = 2,
      },
      {
        item_name = 'destroy-biter-spawner',
        icons = {'item/pistol'},
        goal = 1,
      }
    }

    global.compilatron.reset = true
    effects.unlock_technologies('fortify')
    quest_gui.set('fortify', quest_layout)
    quest_gui.add_hint({'quest-hints.info-spawners-consume-pollution'})
        quest_gui.add_hint({'quest-hints.info-production'})
    pollution.set_vanilla_attack_state(locations.get_main_surface(),true)
    colony_controller.change_all_colony_force('enemy')
    colony_controller.deregister('colony-west-mid')
    quest_gui.visible(true)
  end,

  condition = function()
    local firearm = check.item_produced_per_time('firearm-magazine',defines.flow_precision_index.one_minute,50)
    local packs = check.item_consumed_per_time('automation-science-pack',defines.flow_precision_index.one_minute,12)
    local loaded = check.number_of_loaded_turrets_in_areas({'defend-2'}, 2, true)
    local destroy = check.player_force_killed('biter-spawner',1)

    local researched = check.research_level_complete('demo-shooting-speed-1',3,false)
    if researched then
      quest_gui.update_count('consume-per-time-automation-science-pack', 12, 12)
    end

    return firearm and (packs or researched) and destroy and loaded
  end,

  update = function()
    attacks.check_spawn_wave('pistol-east')
  end,

  action = function()
    quest_gui.unset()
  end,
}

second_base.story_nodes['trigger-map-expansion'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'arrive-compi-trigger-cutscene-pond',
      },
    }

    global.compilatron.reset = true
    quest_gui.set('trigger-freeplay', quest_layout)
    quest_gui.visible(true)
  end,

  condition = function()
    local arrive = check.player_inside_area('compi-trigger-cutscene-pond')
    return arrive
  end,

  update = function()
    attacks.check_spawn_wave('pistol-east')
  end,

  action = function()
    quest_gui.visible(false)
  end
}

second_base.story_nodes['final-expansion'] =
{
  init = function()
    effects.expand_map(expansions['final'])
  end,

  condition = function()
    return not cutscene.is_any_cutscene_playing()
  end
}

second_base.story_nodes['biters-from-east'] =
{
  init = function()
    local spawn = locations.get_pos('spawn-east')
    local rally = locations.get_area('pond-copper-targets')
    local target = locations.get_area('pond-copper-targets')
    if spawn and rally and target then
      --make some biters!
      attack.spawn_attack_wave_no_groups(5,spawn,rally,{'burner-mining-drill','electric-mining-drill'},target,50000,'enemy')
    end
    popup.clear_all()
    cutscene.play(scenes['biters-from-east'])
  end,
  condition = function()
    return not cutscene.is_any_cutscene_playing()
  end
}

second_base.story_nodes['long-research'] =
{
  init = function()
    local quest_layout =
    {
      {
        item_name = 'research-demo-munitions-upgrade',
      },
    }

    global.compilatron.reset = true
    effects.unlock_technologies('long-research')
    quest_gui.add_hint({'quest-hints.info-expand-defense'})
    quest_gui.add_hint({'quest-hints.info-copy-paste-settings'})
    quest_gui.add_hint({'quest-hints.info-pipette'})
    quest_gui.set('long-research', quest_layout)
    pollution.reset()
    quest_gui.visible(true)
    pollution.set_vanilla_attack_state(locations.get_main_surface(),true)
    pollution.reduce_pollution_to_minimum(locations.get_main_surface())
    game.auto_save("demo-final-quest")
  end,

  condition = function()
    local researched = check.research_list_complete({'demo-munitions-upgrade'},false)
    return researched
  end,

  action = function()
    effects.activate_side_menu(true)
    quest_gui.unset()
  end,
}

second_base.story_nodes['victory'] =
{
  init = function()
    game.set_game_state({game_finished=true, player_won=true, can_continue=true})
  end,
}

second_base.story_nodes['freeplay'] =
{
  init = function()
    quest_gui.visible(false)
  end,
}

for name, node in pairs(second_base.story_nodes) do
    node.name = name
end

return second_base