--- NPE Scenario Story Table
-- @module story
-- storage for the story table, and event handler for conditions.lua

local story = require('story_2')
local pollution = require(mod_name .. ".lualib.pollution")
local campaign_util = require(mod_name .. ".lualib.campaign_util")

local cutscenes =
{
  compi_build_iron_cutscene = require('cutscenes.compi_build_iron_cutscene'),
  biters_revealed = require('cutscenes.biters_revealed'),
  biters_close_in = require('cutscenes.biters_close_in'),
  east_flank_worms = require('cutscenes.east_flank_worms'),
  west_spawner_close = require('cutscenes.west_spawner_close'),
  base_destroyed_east_revealed = require('cutscenes.base_destroyed_east_revealed')
}

local stages =
{
  starting_area = require('story_nodes.starting_area'),
  second_base = require('story_nodes.second_base')
}

local story_table = {}

local generate_congrats_node = function(unique_name)
  return
  {
    name = 'congrats_' .. unique_name,
    init = function()
      campaign_util.flying_congrats(game.players[1].position)
      game.forces.player.play_sound({ path = "utility/achievement_unlocked" })
    end,
    condition = function () return story.check_seconds_passed('main_story',2) end
  }
end

local generate_intermission_node = function(unique_name)
  return
  {
    name = 'intermission_' .. unique_name,
    condition = function()
      return story.check_seconds_passed('main_story', 2)
    end
  }
end


local story_nodes
local get_story_nodes = function()
  if story_nodes == nil then
    story_nodes = {}

    local add = function(data)
      if data[1] then -- data is a table of multiple nodes
        for _, node in pairs(data) do
          table.insert(story_nodes, node)
        end
      else -- data is just one node
        table.insert(story_nodes, data)
      end
    end
    add(stages.starting_area.story_nodes['intro'])
    add(stages.starting_area.story_nodes['explore'])
    add(generate_congrats_node("explore"))
    add(stages.starting_area.story_nodes['handmining'])
    add(generate_congrats_node("handmining"))
    add(stages.starting_area.story_nodes['smelting'])
    add(generate_congrats_node("smelting"))
    add(stages.starting_area.story_nodes['automining'])
    add(generate_congrats_node("automining"))
    add(stages.starting_area.story_nodes['handcrafting'])
    add(generate_congrats_node("handcrafting"))
    add(stages.starting_area.story_nodes['trigger-build'])
    add(cutscenes.compi_build_iron_cutscene.generate_cutscene())
    add(stages.starting_area.story_nodes['repair-assembler'])
    add(generate_congrats_node("repair-assembler"))
    add(stages.starting_area.story_nodes['power-assembler'])
    add(generate_congrats_node("power-assembler"))
    add(stages.starting_area.story_nodes['repair-lab'])
    add(generate_congrats_node("repair-lab"))
    add(stages.starting_area.story_nodes['load-lab'])
    add(generate_congrats_node("load-lab"))
    add(stages.starting_area.story_nodes['electronics'])
    add(generate_congrats_node("electronics"))
    add(stages.starting_area.story_nodes['build-radar'])
    add(generate_congrats_node("build-radar"))
    add(stages.starting_area.story_nodes['trigger-radar'])
    add(cutscenes.biters_revealed.generate_cutscene())
    add(generate_intermission_node("west-expansion"))
    add(stages.starting_area.story_nodes['scan-wreck'])
    add(generate_congrats_node("scan-wreck"))
    add(stages.starting_area.story_nodes['trigger-attacks'])
    add(cutscenes.biters_close_in.generate_cutscene())
    add(generate_intermission_node('biters-close-in'))
    --add(misc.generate_screenshot_area_node('demo_17_4', 'starting-area', 'a'))
    add(stages.starting_area.story_nodes['prepare'])
    add(generate_congrats_node("prepare"))
    add(stages.starting_area.story_nodes['leave'])
    add(generate_congrats_node("leave"))
    add(cutscenes.base_destroyed_east_revealed.generate_cutscene())
    add(generate_intermission_node('east-expansion'))
    add(stages.second_base.story_nodes['reach-pond'])
    add(generate_congrats_node("reach-pond"))
    add(stages.second_base.story_nodes['rebuild'])
    add(generate_congrats_node("rebuild"))
    add(stages.second_base.story_nodes['military'])
    add(generate_congrats_node("military"))
    add(stages.second_base.story_nodes['entrench'])
    add(generate_congrats_node("entrench"))
    add(stages.second_base.story_nodes['trigger-west-spawner'])
    add(cutscenes.west_spawner_close.generate_cutscene())
    add(stages.second_base.story_nodes['fortify'])
    add(generate_congrats_node("fortify"))
    add(generate_intermission_node('fortify'))
    add(stages.second_base.story_nodes['trigger-map-expansion'])
    add(stages.second_base.story_nodes['final-expansion'])
    add(generate_intermission_node('final_expansion'))
    add(cutscenes.east_flank_worms.generate_cutscene())
    --add(misc.generate_screenshot_area_node('demo_17_4', 'second-base-area','b'))
    add(stages.second_base.story_nodes['long-research'])
    add(generate_congrats_node("long-research"))
    --add(misc.generate_screenshot_area_node('demo_17_4', 'second-base-area','c'))
    add(stages.second_base.story_nodes['victory'])
    add(generate_intermission_node('victory'))
    add(stages.second_base.story_nodes['freeplay'])
  end

  return story_nodes
end

local check_story_and_pollution = function(event)
  if active_player() then
    story.update("main_story", event)
  end

  pollution.check_pollution()
end

story_table.init = function()
  if campaign_debug_mode then
    print("ON_INIT: storytable")
  end
  story.init("main_story", get_story_nodes())

  if campaign_debug_mode then
    story.set_debug("main_story", true)
  end
end

story_table.on_load = function()
  if campaign_debug_mode then
    print("ON_LOAD: storytable")
  end
  story.on_load("main_story", get_story_nodes())
end

story_table.events = {
  [defines.events.on_tick] = check_story_and_pollution,
  [defines.events.on_built_entity] = check_story_and_pollution,
}

return story_table


