local waves = {}

--[[
VALID SPAWNS
spawn-west
spawn-east
spawn-north
spawn-south

VALID TARGETS
iron-production-targets
crash-packup-targets
pond-iron-targets
pond-copper-targets
pond-stone-targets
iron-south-targets
copper-south-targets
coal-north-targets
iron-north-targets
second-base-area

VALID RALLY POINTS
north-west-canyon-rally
south-west-canyon-rally
south-east-canyon-rally
north-east-canyon-rally
north-crash-rally
south-crash-rally
south-shallows-rally
canyon-middle-rally

]]

waves['demo'] = {
  name = 'demo',
  --costs can be an integer or a table. If a table is provided then the modifiers are checked.
  --1 is roughly 100% of factory production
  --1.2 is is ok for very slow increase in stockpiled ammo
  --2.5 is easy for me to stabilize
  -- values higher than 20 are useful to keep a steady attack, which will only defeat completely empty turret lines
  cost = {
    minimum = 100,
    maximum = 200,
    },
  -- Each modifier is calculated and returns a number between 0 and 1. The average of all modifiers is used to determine the
  -- actual cost.
  modifiers = {
    {
      name = 'ten_minutes',
      weight = 1
    },
  },
  wave = 1,
  vector = {
    {
      spawn = {'spawn-west'},
      rally = {'north-crash-rally'},--rally points must be valid ScriptPosition names
      target = {'crash-packup-targets'},--targets must be a valid ScriptArea names
      target_types = {'burner-mining-drill','stone-furnace','gun-turret'},
      mission = 'attack',
      allowed_biter_types = {
        {name='small-biter',modifier=1,min=1,max=50},
      }
    }
  }
}

waves['packup'] = {
  name = 'packup',
  cost = {
    minimum = 5,
    maximum = 40,
  },
  modifiers = {
    {
      name = "ten_minutes",
      weight = 1
    },
  },
  wave = 5,
  vector = {
    {
      spawn = {'spawn-west'},
      rally = {'north-crash-rally'},
      target = {'starting-area'},
      target_types = {'burner-mining-drill','stone-furnace','burner-inserter','small-electric-pole','assembling-machine-1'},
      mission = 'attack',
      allowed_biter_types = {
        {name='small-biter',modifier=1,min=5,max=5},
      }
    }
  }
}

waves['pistol-west'] = {
  name = 'pistol-west',
  cost = 75,
  modifiers = {},
  wave = 1,
  vector = {
    {
      spawn = {'spawn-west'},
      rally = {'canyon-middle-rally'},
      target = {'pond-iron-targets'},
      target_types = {'burner-mining-drill','electric-mining-drill','stone-furnace','small-electric-pole'},
      mission = 'attack',
      allowed_biter_types = {
        {name='small-biter',modifier=1,min=1,max=50},
      }
    }
  }
}

waves['pistol-east'] = {
  name = 'pistol-east',
  cost = 75,
  modifiers = {},
  wave = 1,
  vector = {
    {
      spawn = {'spawn-east'},
      rally = {"colony-east-top","colony-east-mid","colony-east-bottom"},
      target = {'pond-copper-targets'},
      target_types = {'burner-mining-drill','electric-mining-drill','stone-furnace','small-electric-pole'},
      mission = 'attack',
      allowed_biter_types = {
        {name='small-biter',modifier=1,min=1,max=50},
      }
    }
  }
}

return waves
